@@ -29,7 +29,7 @@ __PACKAGE__->use_log4perl( level => 'warn' );
 use parent qw(CLI::Simple);
 
 ########################################################################
-our $VERSION = '1.0.9';
+our $VERSION = '1.0.10';
 ########################################################################
 
 use File::Basename;  # <-- Make sure to 'use' this at the top of the file
@@ -419,6 +419,9 @@ sub resolve_stream {
 
   my $output = $EMPTY;
 
+  return $output
+    if !$fh || $fh->eof();
+
   while ( my $line = <$fh> ) {
     if ( $line =~ /[$][{](.*)[}]/xsm ) {
       my $ref = $resolver->resolve( { value => $line }, $parameters );
